@@ -32,7 +32,8 @@ import numpy as np
 from functools import partial
 from operator import getitem
 
-from ..topology_graph import TopologyGraph, EdgeGroup
+from ..topology_graph import TopologyGraph, NullOptimizer, EdgeGroup
+from .vertices import _UnaligningVertex
 from .edge import _CofEdge
 from ...reactions import GenericReactionFactory
 
@@ -65,6 +66,8 @@ class Cof(TopologyGraph):
     the :attr:`_vertex_prototypes` and :attr:`_edge_prototypes` class
     attributes.
 
+    .. _cof-topology-graph-examples:
+
     Examples
     --------
     *Subclass Implementation*
@@ -88,6 +91,24 @@ class Cof(TopologyGraph):
             topology_graph=stk.cof.Honeycomb((bb1, bb2), (3, 3, 1)),
         )
 
+    *Suggested Optimization*
+
+    For :class:`.Cof` topologies, it is recommend to use the
+    :class:`.Collapser` optimizer if using the nonperiodic form.
+    However, no optimizer is valid for periodic systems currently.
+
+    .. code-block:: python
+
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.Honeycomb(
+                building_blocks=(bb1, bb2),
+                lattice_size=(3, 3, 1),
+                # Setting scale_steps to False tends to lead to a
+                # better structure.
+                optimizer=stk.Collapser(scale_steps=False),
+            ),
+        )
+
     *Accessing the Periodic Unit Cell*
 
     The same :class:`.Cof` instance can be built as a periodic
@@ -199,6 +220,7 @@ class Cof(TopologyGraph):
         vertex_alignments=None,
         reaction_factory=GenericReactionFactory(),
         num_processes=1,
+        optimizer=NullOptimizer(),
     ):
         """
         Initialize a :class:`.Cof` instance.
@@ -246,6 +268,10 @@ class Cof(TopologyGraph):
             The number of parallel processes to create during
             :meth:`construct`.
 
+        optimizer : :class:`.Optimizer`, optional
+            Used to optimize the structure of the constructed
+            molecule.
+
         Raises
         ------
         :class:`AssertionError`
@@ -312,6 +338,10 @@ class Cof(TopologyGraph):
                 )
             )
 
+        building_block_vertices = self._with_unaligning_vertices(
+            building_block_vertices=building_block_vertices,
+        )
+
         self._check_building_block_vertices(
             num_vertices=(
                 np.product(lattice_size)*len(self._vertex_prototypes)
@@ -324,9 +354,24 @@ class Cof(TopologyGraph):
             reaction_factory=reaction_factory,
             construction_stages=(),
             num_processes=num_processes,
+            optimizer=optimizer,
             edge_groups=self._get_edge_groups(edges),
         )
 
+    @staticmethod
+    def _with_unaligning_vertices(building_block_vertices):
+        clone = dict(building_block_vertices)
+        for building_block, vertices in clone.items():
+            # Building blocks with 1 placer, cannot be aligned and
+            # must therefore use an UnaligningVertex.
+            if len(set(building_block.get_placer_ids())) == 1:
+                clone[building_block] = tuple(map(
+                    _UnaligningVertex,
+                    vertices,
+                ))
+
+        return clone
+
     @classmethod
     def _check_building_block_vertices(
         cls,
