@@ -116,6 +116,7 @@ class TopologyGraph:
         reaction_factory,
         construction_stages,
         num_processes,
+        optimizer,
         edge_groups=None,
     ):
         """
@@ -159,6 +160,10 @@ class TopologyGraph:
             The number of parallel processes to create during
             :meth:`construct`.
 
+        optimizer : :class:`.Optimizer`
+            Used to optimize the structure of the constructed
+            molecule.
+
         edge_groups : :class:`tuple` of :class:`.EdgeGroup`, optional
             The edge groups of the topology graph, if ``None``, every
             :class:`.Edge` is in its own edge group.
@@ -194,6 +199,8 @@ class TopologyGraph:
             )
         self._edge_groups = edge_groups
 
+        self._optimizer = optimizer
+
     def _with_building_blocks(self, building_block_map):
         """
         Modify the topology graph.
@@ -303,6 +310,7 @@ class TopologyGraph:
         clone._edges = self._edges
         clone._reaction_factory = self._reaction_factory
         clone._implementation = self._implementation
+        clone._optimizer = self._optimizer
         clone._edge_groups = self._edge_groups
         return clone
 
@@ -395,6 +403,7 @@ class TopologyGraph:
         state = self._get_construction_state()
         state = self._place_building_blocks(state)
         state = self._run_reactions(state)
+        state = self._optimizer.optimize(state)
         return ConstructionResult(state)
 
     def _get_construction_state(self):
@@ -404,7 +413,7 @@ class TopologyGraph:
             lattice_constants=tuple(
                 np.array(constant, dtype=np.float64)*self._scale
                 for constant in self._get_lattice_constants()
-            )
+            ),
         )
 
     def _get_scale(self, building_block_vertices):
